Ext.define('DSS.addon.ValveEditor', {
	extend : 'Ext.window.Window',
	editControls : {},
	buttonSave : null,
	buttonCancel : null,

	saveValveProtection : function() {
		var weekday = this.valveProtectionTime.getValue().valveProtectionWeekday;
		var offset = this.valveProtectionStart.getValue();
		var duration = this.valveProtectionInterval.getValue();
		switch (weekday) {
		case 'MO':
			offset += 0 * 24 * 60 * 60;
			break;
		case 'TU':
			offset += 1 * 24 * 60 * 60;
			break;
		case 'WE':
			offset += 2 * 24 * 60 * 60;
			break;
		case 'TH':
			offset += 3 * 24 * 60 * 60;
			break;
		case 'FR':
			offset += 4 * 24 * 60 * 60;
			break;
		case 'SA':
			offset += 5 * 24 * 60 * 60;
			break;
		case 'SU':
			offset += 6 * 24 * 60 * 60;
			break;
		}
		;
		dss.raiseEvent('heating-controller.valve-protection', {
			actions : 'configure',
			startTime : offset,
			duration : duration
		});
	},

	constructor : function(config) {
		var me = this;
		this.value = {};
		config.closeAction = 'hide';
		config.modal = true;
		config.height = 120;
		config.width = 720;
		config.layout = 'fit';
		config.appName = '';
		config.resizable = false;

		config.title = _('Configure valve settings');

		me.valveProtectionTime = Ext.create('Ext.form.RadioGroup', {
			labelWidth : 260,
			width : 700,
			fieldLabel : _('Valve protection should be executed on'),
			items : [ {
				boxLabel : _('MO'),
				name : 'valveProtectionWeekday',
				inputValue : 'MO',
				style : {
					padding : '10px',
					color : "#005138"
				}
			}, {
				boxLabel : _('TU'),
				name : 'valveProtectionWeekday',
				inputValue : 'TU',
				style : {
					padding : '10px',
					color : "#005138"
				}
			}, {
				boxLabel : _('WE'),
				name : 'valveProtectionWeekday',
				inputValue : 'WE',
				style : {
					padding : '10px',
					color : "#005138"
				}
			}, {
				boxLabel : _('TH'),
				name : 'valveProtectionWeekday',
				inputValue : 'TH',
				style : {
					padding : '10px',
					color : "#005138"
				}
			}, {
				boxLabel : _('FR'),
				name : 'valveProtectionWeekday',
				inputValue : 'FR',
				style : {
					padding : '10px',
					color : "#005138"
				}
			}, {
				boxLabel : _('SA'),
				name : 'valveProtectionWeekday',
				inputValue : 'SA',
				style : {
					padding : '10px',
					color : "#005138"
				}
			}, {
				boxLabel : _('SU'),
				name : 'valveProtectionWeekday',
				inputValue : 'SU',
				style : {
					padding : '10px',
					color : "#005138"
				}
			} ]
		});
		me.valveProtectionStart = Ext.create('DSS.component.TimeSpanControl', {
			labelWidth : 260,
			width : 450,
			hideSecond : true,
			fieldLabel : _('valve protection starting hour')
		});
		me.valveProtectionInterval = Ext.create('DSS.component.TimeSpanControl', {
			labelWidth : 130,
			width : 400,
			hideSecond : true,
			hideHour : true,
			fieldLabel : _('valve protection delay')
		});

		var sString = dss.ajaxSyncRequest('/json/property/query', {
			'query' : '/scripts/heating-controller/generalSettings(*)'
		});
		try {
			var result = Ext.JSON.decode(sString);
			if (result.ok) {
				if (result.result != null)
					if (result.result.generalSettings != null) {
						if (result.result.generalSettings[0] != null) {
							if (result.result.generalSettings[0].valveProtectionWeekday != null) {
								me.valveProtectionTime.setValue({
									valveProtectionWeekday : result.result.generalSettings[0].valveProtectionWeekday
								});
							}
							if (result.result.generalSettings[0].valveProtectionStartTime != null) {
								me.valveProtectionStart.setValue(result.result.generalSettings[0].valveProtectionStartTime);
							}
							if (result.result.generalSettings[0].valueProtectionTimeFrame != null) {
								me.valveProtectionInterval.setValue(result.result.generalSettings[0].valueProtectionTimeFrame);
							}

						}
					}
			}
		} catch (e) {
		}

		me.buttonSave = Ext.create('Ext.Button', {
			text : _('save'),
			handler : function() {
				me.saveValveProtection();
				me.hide();
			}
		});
		me.buttonCancel = Ext.create('Ext.Button', {
			text : _('cancel'),
			handler : function() {
				me.hide();
			}
		});
		this.displayBottomText = Ext.create('Ext.form.field.Display', {
			border : 0,
			value : '',
			style : {
				fontSize : '11px'
			},
			padding : '0 0 2 5',
			flex : 1
		});

		Ext.apply(me, {
			items : [ {
				xtype : 'panel',
				items : [ me.valveProtectionTime, {
					xtype : 'panel',
					border : false,
					layout : 'hbox',
					items : [ me.valveProtectionStart, me.valveProtectionInterval ]
				} ],
				bodyPadding : 5,
				border : 0,
				dockedItems : [ {
					xtype : 'toolbar',
					dock : 'bottom',
					ui : 'footer',
					defaults : {
						minWidth : 75
					},
					items : [ '->', me.buttonSave, me.buttonCancel ]
				} ]
			} ]
		}); // Ext.apply
		this.callParent(arguments);
	}
});
